import numpy as np
from HtRxnPFn import HtRxnP
from SpecVolFn import SpecVol
from FindTFn import findT
def PBRFull(v,y,FeedN2,FeedH2,FeedAr,FeedCH4,FeedT,
            k0f,Ef,k0r,Er,eps,nu,G0,Dp,Ar,
            MWN2,MWH2,MWNH3,MWAr,MWCH4,CpCoef):
    Rgas = 8.314  # kJ/kmol/K
    # unpack dependent variables
    MflowN2 = y[0]
    P = y[1]
    H = y[2]
    # algebraic equations from stoichiometry for H2 and NH3
    MflowH2 = FeedH2 - 3*(FeedN2 - MflowN2)
    MflowNH3 = 2*(FeedN2 - MflowN2)
    # total molar flow
    TotFlow = MflowN2+MflowH2+MflowNH3+FeedAr+FeedCH4
    # partial pressures - atm
    PN2 = MflowN2/TotFlow*P
    PH2 = MflowH2/TotFlow*P 
    PNH3 = MflowNH3/TotFlow*P 
    # find T from H
    T = 350
    T = findT(H,T,MflowN2,MflowH2,MflowNH3,FeedAr,FeedCH4,CpCoef)
    # forward and reverse reaction rates
    rf = k0f*np.exp(-Ef/Rgas/(T+273.15))+PN2**0.5*PH2**1.5
    rr = k0r*np.exp(-Er/Rgas/(T+273.15))*PNH3
    # differential balance on N2 in kmol/h/m3
    dy = np.zeros(3)
    dy[0] = -(rf-rr)*eps
    # average molecular weight
    MWavg = (MflowN2*MWN2+MflowH2*MWH2+MflowNH3*MWNH3 \
             +FeedAr*MWAr+FeedCH4*MWCH4)/TotFlow
    # gas density
    z = np.array([MflowN2, MflowH2, MflowNH3, FeedAr, FeedCH4])/TotFlow
    w = np.array([ 0.039, -0.216, 0.25, 0.001, 0.011])
    Tc = np.array([126.2, 33.19, 405.65, 150.86, 190.564])
    Pc = np.array([3394, 1297, 11277, 4870, 4641])
    K = np.array([[0, -0.036, 0.222, 0, 0.036],
                  [-0.036, 0, 0, 0, 0.202],
                  [0.222, 0, 0, 0, 0],
                  [0, 0, 0, 0, 0.023],
                  [0.036, 0.202, 0, 0.023, 0]])
    SV = SpecVol(T,P,z,w,Tc,Pc,K)
    RhoGas = MWavg/SV
    # gas viscosity from mu and RhoGas
    mu = nu * RhoGas
    # differential Ergun equation, dP/dV in atm/m3
    dy[1] = -(150*(1-eps)/Dp/G0*mu+7/4)*(1-eps)/eps**3/Dp \
            /RhoGas*G0**2/Ar/101325
        # differential energy balance
    HtRx = HtRxnP(T,P)
    dy[2] = (rf-rr)*(-HtRx)*eps
    return dy

