import numpy as np
from HtRxnFn import HtRxn
def PBRsimplified(v,y,FeedN2,FeedH2,FeedAr,FeedCH4,P, \
                  k0f,Ef,k0r,Er,eps,CpN2,CpH2,CpNH3,CpAr,CpCH4):
    Rgas = 8.314  # kJ/kmol/K
    # unpack dependent variables
    MflowN2 = y[0]
    T = y[1]
    # algebraic equations from stoichiometry for H2 and NH3
    MflowH2 = FeedH2 - 3*(FeedN2 - MflowN2)
    MflowNH3 = 2*(FeedN2 - MflowN2)
    # total molar flow
    TotFlow = MflowN2+MflowH2+MflowNH3+FeedAr+FeedCH4
    # partial pressures - atm
    PN2 = MflowN2/TotFlow*P
    PH2 = MflowH2/TotFlow*P 
    PNH3 = MflowNH3/TotFlow*P 
    # forward and reverse reaction rates
    rf = k0f*np.exp(-Ef/Rgas/(T+273.15))+PN2**0.5*PH2**1.5
    rr = k0r*np.exp(-Er/Rgas/(T+273.15))*PNH3
    # differential balance on N2 in kmol/h/m3
    dy = np.zeros(2)
    dy[0] = -(rf-rr)*eps
    # differential energy balance
    HtRx = HtRxn(T)
    dy[1] = (rf-rr)*(-HtRx)*eps/ \
            (MflowH2*CpN2+MflowH2*CpH2+MflowNH3*CpNH3 \
             +FeedAr*CpAr+FeedCH4*CpCH4)
    return dy

